==> haskell-tasty-hunit-0.10.0.1-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-hunit.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-hunit
version: 0.10.0.1
id: tasty-hunit-0.10.0.1-AdUB3u1hXLU56UGLe58tH7
key: tasty-hunit-0.10.0.1-AdUB3u1hXLU56UGLe58tH7
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/tasty
synopsis: HUnit support for the Tasty test framework.
description:
    HUnit support for the Tasty test framework.
category: Testing
author: Roman Cheplyaka <roma@ro-che.info>
exposed: True
indefinite: False
exposed-modules:
    Test.Tasty.HUnit
hidden-modules: Test.Tasty.HUnit.Orig Test.Tasty.HUnit.Steps
abi: 759640112ab2e79891788c358074a97a
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/tasty-hunit-0.10.0.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/tasty-hunit-0.10.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/tasty-hunit-0.10.0.1
hs-libraries: HStasty-hunit-0.10.0.1-AdUB3u1hXLU56UGLe58tH7
depends:
    base-4.10.1.0 tasty-0.12.0.1-BrMOfOJpa4GCtpWs3V78qY
    call-stack-0.1.0-BVjoAlBRe9FCSr5eFfllei
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             tasty-0.12.0.1-BrMOfOJpa4GCtpWs3V78qY=735f36c898ebe4cd62d386315e2e8f2d
             call-stack-0.1.0-BVjoAlBRe9FCSr5eFfllei=80879ea65722c5998aff02ea5d901642
haddock-interfaces: /usr/share/doc/haskell-tasty-hunit/html/tasty-hunit.haddock
haddock-html: /usr/share/doc/haskell-tasty-hunit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-hunit-0.10.0.1-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-hunit.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-hunit
version: 0.10.0.1
id: tasty-hunit-0.10.0.1-KQJaXuU4NHk3wotkdvkBNZ
key: tasty-hunit-0.10.0.1-KQJaXuU4NHk3wotkdvkBNZ
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/tasty
synopsis: HUnit support for the Tasty test framework.
description:
    HUnit support for the Tasty test framework.
category: Testing
author: Roman Cheplyaka <roma@ro-che.info>
exposed: True
indefinite: False
exposed-modules:
    Test.Tasty.HUnit
hidden-modules: Test.Tasty.HUnit.Orig Test.Tasty.HUnit.Steps
abi: c90aa04ce7f93bae09b86f0eebf5bacd
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/tasty-hunit-0.10.0.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/tasty-hunit-0.10.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/tasty-hunit-0.10.0.1
hs-libraries: HStasty-hunit-0.10.0.1-KQJaXuU4NHk3wotkdvkBNZ
depends:
    base-4.10.1.0 tasty-1.0.1-AWWNaFTEpDABJ6I60QHIFP
    call-stack-0.1.0-BVjoAlBRe9FCSr5eFfllei
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             tasty-1.0.1-AWWNaFTEpDABJ6I60QHIFP=676bfe39e5968a7e880bebc46f35c0bf
             call-stack-0.1.0-BVjoAlBRe9FCSr5eFfllei=80879ea65722c5998aff02ea5d901642
haddock-interfaces: /usr/share/doc/haskell-tasty-hunit/html/tasty-hunit.haddock
haddock-html: /usr/share/doc/haskell-tasty-hunit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
